==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontDoorManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property exclusions Describes the exclusions that are applied to this specific rule.
 * @property ruleId Identifier for the managed rule.
 */
public data class FrontDoorManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val exclusions: Output<List<ManagedRuleExclusionArgs>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs =
        com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .exclusions(
                exclusions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FrontDoorManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class FrontDoorManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var exclusions: Output<List<ManagedRuleExclusionArgs>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("bdeqighpkaonuijy")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("kvtxtjqeqgbbneed")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("huhfpnurvmfqnuig")
    public suspend fun exclusions(`value`: Output<List<ManagedRuleExclusionArgs>>) {
        this.exclusions = value
    }

    @JvmName("rwqmwnwrqshkwivr")
    public suspend fun exclusions(vararg values: Output<ManagedRuleExclusionArgs>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("klnjidsgoxwtrtwx")
    public suspend fun exclusions(values: List<Output<ManagedRuleExclusionArgs>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("ypxjuwtmjeainkru")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("cumqgfvxijqigwgw")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("cciprgwbunjmbega")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("yipnhgnakdibfyqs")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("lykalpstwneneywx")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("hkodvkjjbpnuycpq")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("iyoecidtfqjrscva")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("oeusacemulpfgfag")
    public suspend fun exclusions(`value`: List<ManagedRuleExclusionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("hampfvuwrcjllnlt")
    public suspend
    fun exclusions(argument: List<suspend ManagedRuleExclusionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("rjdagpypsoagojct")
    public suspend fun exclusions(
        vararg
        argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("gutjedjeqykvfwad")
    public suspend fun exclusions(argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleExclusionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("yhaelxrlswqbrpcq")
    public suspend fun exclusions(vararg values: ManagedRuleExclusionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("qobsxrtjmmjdhqmm")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): FrontDoorManagedRuleOverrideArgs = FrontDoorManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        exclusions = exclusions,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontDoorManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property exclusions Describes the exclusions that are applied to this specific rule.
 * @property ruleId Identifier for the managed rule.
 */
public data class FrontDoorManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val exclusions: Output<List<ManagedRuleExclusionArgs>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs =
        com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .exclusions(
                exclusions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FrontDoorManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class FrontDoorManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var exclusions: Output<List<ManagedRuleExclusionArgs>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("lfgfouotfbmwtqbv")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("dywdapbcvembmypm")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("ijpjiemuhkjstvwe")
    public suspend fun exclusions(`value`: Output<List<ManagedRuleExclusionArgs>>) {
        this.exclusions = value
    }

    @JvmName("umeyunaumjcbfqjt")
    public suspend fun exclusions(vararg values: Output<ManagedRuleExclusionArgs>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("ahueowqbygxwglip")
    public suspend fun exclusions(values: List<Output<ManagedRuleExclusionArgs>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("xvbctkrhdalvfaps")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("bhxlvxwarnnwewul")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("etrwqlpqguumcowr")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("wtjqktpfnfsfaowx")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("uontfeyorcynrnfv")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("gittioaepgolwaei")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("hardqydlgvroavaw")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("muukvbceskhoitfs")
    public suspend fun exclusions(`value`: List<ManagedRuleExclusionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("klhfdufkdjdkdauo")
    public suspend
    fun exclusions(argument: List<suspend ManagedRuleExclusionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("ytvtajmheuinbehw")
    public suspend fun exclusions(
        vararg
        argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("puhfkyuhaiwecvxm")
    public suspend fun exclusions(argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleExclusionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("sjdbihahktscmknm")
    public suspend fun exclusions(vararg values: ManagedRuleExclusionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("edmerrtsugydvija")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): FrontDoorManagedRuleOverrideArgs = FrontDoorManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        exclusions = exclusions,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}
